*--------------------------------------------------------------------*
*	Author		 : Vinayak Alladi								     *
*	Email		 : valladi@worldbank.org							 *
*	Version		 : 23 October 2023							         *
*--------------------------------------------------------------------*

clear all
set more off
set seed 10051990 

*Please update directories for the following dofile:

*User's local directory for data
	global msLocal 	= "C:\WBG\github\217v6\Reproducibility resubmission v5\Reproducibility resubmission"

*Subfolder of Informality Analysis

global Do		   	= "${msLocal}/Do/Vinayak"
global Raw_Data		= "${msLocal}/Raw Data"
global Created_Data = "${msLocal}/Created Data"
global Graph 		= "${msLocal}/Graph"

**Use Data File
use "$Raw_Data/M2_F.dta", clear
keep hhid m2f5a2

foreach var in m2f5a2 {
                destring `var', ignore(____.____) replace
                format `var' %20.0fc
                replace `var'=. if `var'>=999000000000
                }

*Variable revenue2 corresponds to question F5a2 in the WEHS-Module 2 (M2F5a2 in the WEHS questionnaire)
ren m2f5a2 revenue2
label var hhid "UNIQUE IDENTITY OF ENTREPRENEUR HOUSEHOLDS"
label var revenue2 "Total revenue/sales in a regular month"

gen rev_per_year_millions=revenue2*12/1000000
label var rev_per_year_millions "Total revenue/sales in a year (in IDR millions)"

save "$Created_Data/v2 VAT_threshold_graph_data.dta", replace

*Distribution of revenues (Revenue per year)
hist rev_per_year_millions if rev_per_year_millions<=5000, bin(100) xaxis(1 2) ///
xlabel(0(1000)5000, axis(1)) ///
xmtick(5, axis(1)) ///
frac ///
xline(500, lwidth(thin) lcolor(green)) ///
xline(4800, lwidth(thin) lcolor(green)) ///
xla(500 "Hypothetically new VAT threshold" 4800 "VAT threshold", axis(2) labsize(small)) ///
xtitle("", axis(2)) ///
xtitle("Revenue per year (in millions of rupiah)", axis(1))

graph export "$Graph/rev_per_year_millions.pdf", as(pdf) replace